from setuptools import setup

setup(name='3mensolutions_distribution',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['3mensolutions_distribution'],
      author='Emmanuel Ameh',
      author_email='a@b.com',
      zip_safe=False)
